CustomMethodStubber class

Scans // <stackchain:custom> for methods and stubs tests in *_custom_test.dart.

Constructors

CustomMethodStubber({required String root, required StackchainConfig config, Logger? logger, bool dryRun = false})

Properties

config StackchainConfig
final
dryRun bool
final
hashCode int
The hash code for this object.
no setterinherited
logger → Logger
final
root String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stubAll() Future<List<String>>
stubFeature(String feature) Future<List<String>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited