FeatureRenameReport class
Constructors
-
FeatureRenameReport({required String from, required String to, required List<
String> touchedPaths, required QualityReport quality})
Properties
- from → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- quality → QualityReport
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → String
-
final
-
touchedPaths
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited