DoctorEngine class
Extended diagnostics + optional auto-repair for stackchain doctor.
Constructors
- DoctorEngine({required String root, required StackchainConfig config, Logger? logger, bool fix = false, bool skipAnalyze = false, String packageVersion = stackchainPackageVersion})
Properties
- config → StackchainConfig
-
final
- fix → bool
-
final
-
fixed
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → Logger
-
final
- packageVersion → String
-
final
- root → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipAnalyze → bool
-
final
-
suggestions
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
) → Future< QualityReport> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited