MigrationEngine class
Intentional stack evolution (e.g. bloc → cubit, go_router stays).
Constructors
Properties
- cleanup → bool
-
Delete files and packages the previous stack needed and the new one
does not. Disable with
--keep-oldto review leftovers manually.final - dryRun → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → Logger
-
final
- overwritePresentation → bool
-
final
- packageVersion → String
-
final
- root → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipAnalyze → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
MigrationPatch patch) → Future< MigrationReport> -
Applies
patchonto stackchain.yaml + regenerates stack shell + sync. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited